/* Teknisa - Tecnologia em Informtica

Nome: 3939_PEDSTPO - RELATORIO DE COMPOSICAO DO PEDIDO

Descrio:
Rotina para ler a tabela de COMPITEMPED e grava-la na tabela RELCOMPITEMPED em forma de matriz.

Criao:
07/06/2016 - Srgio Pow

@..\Sql\End_Conv\Oracle\3939_PEDSTPO.SQL
*/

create or replace PROCEDURE RELATORIO_COMPITEMPEDIDO (
   P_CDFILIAL      IN ITEMPEDIDO.CDFILIAL%TYPE,
   P_NRPEDIDO      IN ITEMPEDIDO.NRPEDIDO%TYPE
   ) AS
   V_CDPRODUTO     ITEMPEDIDO.CDPRODUTO%TYPE;
   V_NRSEQLINHA    RELCOMPITEMPED.NRSEQLINHA%TYPE;
   V_NRSEQSUBLINHA RELCOMPITEMPED.NRSEQLINHA%TYPE;
   V_NRLINHA       RELCOMPITEMPED.NRLINHA%TYPE;
BEGIN
   V_CDPRODUTO     := '';
   V_NRSEQLINHA    := '';
   V_NRSEQSUBLINHA := '';
   V_NRLINHA       := '';
   
   -- Consulta a composio do produto passado como parmetro.
   FOR C_COMP IN (
          SELECT C.CDFILIAL, C.NRPEDIDO, C.NRITEMPED, C.CDPRODUTO, 
                 C.CDPRODCOMPED, FILHO.NMPRODUTO AS PRODFILHO,
                 C.QTITCOMPPROD, C.VRPREUNICOMP, C.CDGRUPOCOMP, TO_NUMBER(C.NRSEQPROD) AS NRSEQPROD
            FROM COMPITEMPED C, PRODUTO PAI, PRODUTO FILHO
           WHERE (C.CDFILIAL     = P_CDFILIAL    )
             AND (C.NRPEDIDO     = P_NRPEDIDO    )
             AND (C.CDPRODUTO    = PAI.CDPRODUTO  )
             AND (C.CDPRODCOMPED = FILHO.CDPRODUTO)
           ORDER BY C.CDFILIAL, C.NRPEDIDO, C.NRITEMPED, C.NRSEQPROD, C.CDGRUPOCOMP)
   LOOP
   
--NRSEQPROD   = Dia da Semana
--CDGRUPOCOMP = Refeio do Dia
-- A linha  a refeio

      -- Domingo
      IF (C_COMP.NRSEQPROD = '1') THEN

        -- Verifica se a linha existe
        BEGIN
           SELECT MIN(NRSEQLINHA) AS NRSEQLINHA, NRLINHA, CDPRODUTO1
             INTO V_NRSEQLINHA, V_NRLINHA, V_CDPRODUTO
             FROM RELCOMPITEMPED
            WHERE (CDFILIAL     = C_COMP.CDFILIAL   )
              AND (NRPEDIDO     = C_COMP.NRPEDIDO   )
              AND (NRITEMPED    = C_COMP.NRITEMPED  )
              AND (CDPRODUTOPAI = C_COMP.CDPRODUTO  )
              AND (NRLINHA      = C_COMP.CDGRUPOCOMP)
            --  AND ((CDPRODUTO1 IS NULL) OR (C_COMP.CDGRUPOCOMP = NRLINHA))
              AND ROWNUM <= 1
            GROUP BY NRLINHA, CDPRODUTO1;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_NRSEQLINHA := '';
               V_NRLINHA    := '';
               V_CDPRODUTO  := '';
         END;
         
        -- Se a linha no existir o V_NRSEQLINHA e o V_CDPRODUTO vo estar vazios
        IF (((V_NRSEQLINHA = '')OR(V_NRSEQLINHA IS NULL)) AND ((V_CDPRODUTO = '')OR(V_CDPRODUTO IS NULL))) THEN

          -- Insere a linha CDGRUPOCOMP
          INSERT INTO RELCOMPITEMPED (CDFILIAL, NRPEDIDO, NRITEMPED, CDPRODUTOPAI,
                                      NRLINHA, NRSEQLINHA,
                                      CDPRODUTO1, NMPRODUTO1, QTPRODUTO1)
            VALUES (C_COMP.CDFILIAL, C_COMP.NRPEDIDO, C_COMP.NRITEMPED, C_COMP.CDPRODUTO,
                    C_COMP.CDGRUPOCOMP, 1,
                    C_COMP.CDPRODCOMPED, C_COMP.PRODFILHO, C_COMP.QTITCOMPPROD);
                    
        -- Se o V_NRSEQLINHA no estiver vazio e o V_CDPRODUTO estiver
        ELSIF ((V_CDPRODUTO = '')OR(V_CDPRODUTO IS NULL)) THEN

          -- Altera a linha que j existe
          UPDATE RELCOMPITEMPED
             SET CDPRODUTO1    = C_COMP.CDPRODCOMPED,
                 NMPRODUTO1    = C_COMP.PRODFILHO,
                 QTPRODUTO1    = C_COMP.QTITCOMPPROD
           WHERE (CDFILIAL     = C_COMP.CDFILIAL   )
             AND (NRPEDIDO     = C_COMP.NRPEDIDO   )
             AND (NRITEMPED    = C_COMP.NRITEMPED  )
             AND (CDPRODUTOPAI = C_COMP.CDPRODUTO  )
             AND (NRLINHA      = C_COMP.CDGRUPOCOMP)
             AND (NRSEQLINHA   = 1               );
             
        -- Deve se criar uma sublinha
        ELSE
        
           -- Procedure que vai adicionando sublinhas recursivamente conforme a necessidade.
           REL_COMPITEMPED_RECURSIVA (C_COMP.CDFILIAL, C_COMP.NRPEDIDO, C_COMP.NRITEMPED, C_COMP.CDPRODUTO,
                                      C_COMP.CDGRUPOCOMP, 2, C_COMP.CDPRODCOMPED, C_COMP.PRODFILHO, C_COMP.QTITCOMPPROD, C_COMP.NRSEQPROD);
        END IF;
      END IF;

      -- Segunda-Feira
      IF (C_COMP.NRSEQPROD = '2') THEN

        -- Verifica se a linha existe
        BEGIN
           SELECT MIN(NRSEQLINHA) AS NRSEQLINHA, NRLINHA, CDPRODUTO2
             INTO V_NRSEQLINHA, V_NRLINHA, V_CDPRODUTO
             FROM RELCOMPITEMPED
            WHERE (CDFILIAL     = C_COMP.CDFILIAL   )
              AND (NRPEDIDO     = C_COMP.NRPEDIDO   )
              AND (NRITEMPED    = C_COMP.NRITEMPED  )
              AND (CDPRODUTOPAI = C_COMP.CDPRODUTO  )
              AND (NRLINHA      = C_COMP.CDGRUPOCOMP)
              --AND ((CDPRODUTO2 IS NULL) OR (C_COMP.CDGRUPOCOMP = NRLINHA))
              AND ROWNUM <= 1
            GROUP BY NRLINHA, CDPRODUTO2;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_NRSEQLINHA := '';
               V_NRLINHA    := '';
               V_CDPRODUTO  := '';
         END;

        IF (((V_NRSEQLINHA = '')OR(V_NRSEQLINHA IS NULL)) AND ((V_CDPRODUTO = '')OR(V_CDPRODUTO IS NULL))) THEN

          --Insere a linha
          INSERT INTO RELCOMPITEMPED (CDFILIAL, NRPEDIDO, NRITEMPED, CDPRODUTOPAI,
                                      NRLINHA, NRSEQLINHA,
                                      CDPRODUTO2, NMPRODUTO2, QTPRODUTO2)
            VALUES (C_COMP.CDFILIAL, C_COMP.NRPEDIDO, C_COMP.NRITEMPED, C_COMP.CDPRODUTO,
                    C_COMP.CDGRUPOCOMP, 1,
                    C_COMP.CDPRODCOMPED, C_COMP.PRODFILHO, C_COMP.QTITCOMPPROD);

        ELSIF ((V_CDPRODUTO = '')OR(V_CDPRODUTO IS NULL)) THEN

          --Altera a linha que j existe
          UPDATE RELCOMPITEMPED
             SET CDPRODUTO2    = C_COMP.CDPRODCOMPED,
                 NMPRODUTO2    = C_COMP.PRODFILHO,
                 QTPRODUTO2    = C_COMP.QTITCOMPPROD
           WHERE (CDFILIAL     = C_COMP.CDFILIAL   )
             AND (NRPEDIDO     = C_COMP.NRPEDIDO   )
             AND (NRITEMPED    = C_COMP.NRITEMPED  )
             AND (CDPRODUTOPAI = C_COMP.CDPRODUTO  )
             AND (NRLINHA      = C_COMP.CDGRUPOCOMP)
             AND (NRSEQLINHA   = 1               );

        ELSE
        
           -- Procedure que vai adicionando sublinhas recursivamente conforme a necessidade.
           REL_COMPITEMPED_RECURSIVA (C_COMP.CDFILIAL, C_COMP.NRPEDIDO, C_COMP.NRITEMPED, C_COMP.CDPRODUTO,
                                      C_COMP.CDGRUPOCOMP, 2, C_COMP.CDPRODCOMPED, C_COMP.PRODFILHO, C_COMP.QTITCOMPPROD, C_COMP.NRSEQPROD);
        END IF;
      END IF;

      -- Tera-Feira
      IF (C_COMP.NRSEQPROD = '3') THEN

        -- Verifica se a linha existe
        BEGIN
           SELECT MIN(NRSEQLINHA) AS NRSEQLINHA, NRLINHA, CDPRODUTO3
             INTO V_NRSEQLINHA, V_NRLINHA, V_CDPRODUTO
             FROM RELCOMPITEMPED
            WHERE (CDFILIAL     = C_COMP.CDFILIAL   )
              AND (NRPEDIDO     = C_COMP.NRPEDIDO   )
              AND (NRITEMPED    = C_COMP.NRITEMPED  )
              AND (CDPRODUTOPAI = C_COMP.CDPRODUTO  )
              AND (NRLINHA      = C_COMP.CDGRUPOCOMP)
          --    AND ((CDPRODUTO3 IS NULL) OR (C_COMP.CDGRUPOCOMP = NRLINHA))
              AND ROWNUM <= 1
            GROUP BY NRLINHA, CDPRODUTO3;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_NRSEQLINHA := '';
               V_NRLINHA    := '';
               V_CDPRODUTO  := '';
         END;

        IF (((V_NRSEQLINHA = '')OR(V_NRSEQLINHA IS NULL)) AND ((V_CDPRODUTO = '')OR(V_CDPRODUTO IS NULL))) THEN

          --Insere a linha
          INSERT INTO RELCOMPITEMPED (CDFILIAL, NRPEDIDO, NRITEMPED, CDPRODUTOPAI,
                                      NRLINHA, NRSEQLINHA,
                                      CDPRODUTO3, NMPRODUTO3, QTPRODUTO3)
            VALUES (C_COMP.CDFILIAL, C_COMP.NRPEDIDO, C_COMP.NRITEMPED, C_COMP.CDPRODUTO,
                    C_COMP.CDGRUPOCOMP, 1,
                    C_COMP.CDPRODCOMPED, C_COMP.PRODFILHO, C_COMP.QTITCOMPPROD);

        ELSIF ((V_CDPRODUTO = '')OR(V_CDPRODUTO IS NULL)) THEN

          --Altera a linha que j existe
          UPDATE RELCOMPITEMPED
             SET CDPRODUTO3    = C_COMP.CDPRODCOMPED,
                 NMPRODUTO3    = C_COMP.PRODFILHO,
                 QTPRODUTO3    = C_COMP.QTITCOMPPROD
           WHERE (CDFILIAL     = C_COMP.CDFILIAL   )
             AND (NRPEDIDO     = C_COMP.NRPEDIDO   )
             AND (NRITEMPED    = C_COMP.NRITEMPED  )
             AND (CDPRODUTOPAI = C_COMP.CDPRODUTO  )
             AND (NRLINHA      = C_COMP.CDGRUPOCOMP)
             AND (NRSEQLINHA   = 1               );

        ELSE

           -- Procedure que vai adicionando sublinhas recursivamente conforme a necessidade.
           REL_COMPITEMPED_RECURSIVA (C_COMP.CDFILIAL, C_COMP.NRPEDIDO, C_COMP.NRITEMPED, C_COMP.CDPRODUTO,
                                      C_COMP.CDGRUPOCOMP, 2, C_COMP.CDPRODCOMPED, C_COMP.PRODFILHO, C_COMP.QTITCOMPPROD, C_COMP.NRSEQPROD);
        END IF;
      END IF;

      -- Quarta-Feira
      IF (C_COMP.NRSEQPROD = '4') THEN

        -- Verifica se a linha existe
        BEGIN
           SELECT MIN(NRSEQLINHA) AS NRSEQLINHA, NRLINHA, CDPRODUTO4
             INTO V_NRSEQLINHA, V_NRLINHA, V_CDPRODUTO
             FROM RELCOMPITEMPED
            WHERE (CDFILIAL     = C_COMP.CDFILIAL   )
              AND (NRPEDIDO     = C_COMP.NRPEDIDO   )
              AND (NRITEMPED    = C_COMP.NRITEMPED  )
              AND (CDPRODUTOPAI = C_COMP.CDPRODUTO  )
              AND (NRLINHA      = C_COMP.CDGRUPOCOMP)
        --      AND ((CDPRODUTO4 IS NULL) OR (C_COMP.CDGRUPOCOMP = NRLINHA))
              AND ROWNUM <= 1
            GROUP BY NRLINHA, CDPRODUTO4;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_NRSEQLINHA := '';
               V_NRLINHA    := '';
               V_CDPRODUTO  := '';
         END;

        IF (((V_NRSEQLINHA = '')OR(V_NRSEQLINHA IS NULL)) AND ((V_CDPRODUTO = '')OR(V_CDPRODUTO IS NULL))) THEN

          --Insere a linha
          INSERT INTO RELCOMPITEMPED (CDFILIAL, NRPEDIDO, NRITEMPED, CDPRODUTOPAI,
                                      NRLINHA, NRSEQLINHA,
                                      CDPRODUTO4, NMPRODUTO4, QTPRODUTO4)
            VALUES (C_COMP.CDFILIAL, C_COMP.NRPEDIDO, C_COMP.NRITEMPED, C_COMP.CDPRODUTO,
                    C_COMP.CDGRUPOCOMP, 1,
                    C_COMP.CDPRODCOMPED, C_COMP.PRODFILHO, C_COMP.QTITCOMPPROD);

        ELSIF ((V_CDPRODUTO = '')OR(V_CDPRODUTO IS NULL)) THEN

          --Altera a linha que j existe
          UPDATE RELCOMPITEMPED
             SET CDPRODUTO4    = C_COMP.CDPRODCOMPED,
                 NMPRODUTO4    = C_COMP.PRODFILHO,
                 QTPRODUTO4    = C_COMP.QTITCOMPPROD
           WHERE (CDFILIAL     = C_COMP.CDFILIAL   )
             AND (NRPEDIDO     = C_COMP.NRPEDIDO   )
             AND (NRITEMPED    = C_COMP.NRITEMPED  )
             AND (CDPRODUTOPAI = C_COMP.CDPRODUTO  )
             AND (NRLINHA      = C_COMP.CDGRUPOCOMP)
             AND (NRSEQLINHA   = 1               );

        ELSE

           -- Procedure que vai adicionando sublinhas recursivamente conforme a necessidade.
           REL_COMPITEMPED_RECURSIVA (C_COMP.CDFILIAL, C_COMP.NRPEDIDO, C_COMP.NRITEMPED, C_COMP.CDPRODUTO,
                                      C_COMP.CDGRUPOCOMP, 2, C_COMP.CDPRODCOMPED, C_COMP.PRODFILHO, C_COMP.QTITCOMPPROD, C_COMP.NRSEQPROD);
        END IF;
      END IF;

      -- Quinta-Feira
      IF (C_COMP.NRSEQPROD = '5') THEN

        -- Verifica se a linha existe
        BEGIN
           SELECT MIN(NRSEQLINHA) AS NRSEQLINHA, NRLINHA, CDPRODUTO5
             INTO V_NRSEQLINHA, V_NRLINHA, V_CDPRODUTO
             FROM RELCOMPITEMPED
            WHERE (CDFILIAL     = C_COMP.CDFILIAL   )
              AND (NRPEDIDO     = C_COMP.NRPEDIDO   )
              AND (NRITEMPED    = C_COMP.NRITEMPED  )
              AND (CDPRODUTOPAI = C_COMP.CDPRODUTO  )
              AND (NRLINHA      = C_COMP.CDGRUPOCOMP)
         --     AND ((CDPRODUTO5 IS NULL) OR (C_COMP.CDGRUPOCOMP = NRLINHA))
              AND ROWNUM <= 1
            GROUP BY NRLINHA, CDPRODUTO5;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_NRSEQLINHA := '';
               V_NRLINHA    := '';
               V_CDPRODUTO  := '';
         END;

        IF (((V_NRSEQLINHA = '')OR(V_NRSEQLINHA IS NULL)) AND ((V_CDPRODUTO = '')OR(V_CDPRODUTO IS NULL))) THEN

          --Insere a linha
          INSERT INTO RELCOMPITEMPED (CDFILIAL, NRPEDIDO, NRITEMPED, CDPRODUTOPAI,
                                      NRLINHA, NRSEQLINHA,
                                      CDPRODUTO5, NMPRODUTO5, QTPRODUTO5)
            VALUES (C_COMP.CDFILIAL, C_COMP.NRPEDIDO, C_COMP.NRITEMPED, C_COMP.CDPRODUTO,
                    C_COMP.CDGRUPOCOMP, 1,
                    C_COMP.CDPRODCOMPED, C_COMP.PRODFILHO, C_COMP.QTITCOMPPROD);

        ELSIF ((V_CDPRODUTO = '')OR(V_CDPRODUTO IS NULL)) THEN

          --Altera a linha que j existe
          UPDATE RELCOMPITEMPED
             SET CDPRODUTO5    = C_COMP.CDPRODCOMPED,
                 NMPRODUTO5    = C_COMP.PRODFILHO,
                 QTPRODUTO5    = C_COMP.QTITCOMPPROD
           WHERE (CDFILIAL     = C_COMP.CDFILIAL   )
             AND (NRPEDIDO     = C_COMP.NRPEDIDO   )
             AND (NRITEMPED    = C_COMP.NRITEMPED  )
             AND (CDPRODUTOPAI = C_COMP.CDPRODUTO  )
             AND (NRLINHA      = C_COMP.CDGRUPOCOMP)
             AND (NRSEQLINHA   = 1               );

        ELSE

           -- Procedure que vai adicionando sublinhas recursivamente conforme a necessidade.
           REL_COMPITEMPED_RECURSIVA (C_COMP.CDFILIAL, C_COMP.NRPEDIDO, C_COMP.NRITEMPED, C_COMP.CDPRODUTO,
                                      C_COMP.CDGRUPOCOMP, 2, C_COMP.CDPRODCOMPED, C_COMP.PRODFILHO, C_COMP.QTITCOMPPROD, C_COMP.NRSEQPROD);
        END IF;
      END IF;

      -- Sexta-Feira
      IF (C_COMP.NRSEQPROD = '6') THEN

        -- Verifica se a linha existe
        BEGIN
           SELECT MIN(NRSEQLINHA) AS NRSEQLINHA, NRLINHA, CDPRODUTO6
             INTO V_NRSEQLINHA, V_NRLINHA, V_CDPRODUTO
             FROM RELCOMPITEMPED
            WHERE (CDFILIAL     = C_COMP.CDFILIAL   )
              AND (NRPEDIDO     = C_COMP.NRPEDIDO   )
              AND (NRITEMPED    = C_COMP.NRITEMPED  )
              AND (CDPRODUTOPAI = C_COMP.CDPRODUTO  )
              AND (NRLINHA      = C_COMP.CDGRUPOCOMP)
         --     AND ((CDPRODUTO6 IS NULL) OR (C_COMP.CDGRUPOCOMP = NRLINHA))
              AND ROWNUM <= 1
            GROUP BY NRLINHA, CDPRODUTO6;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_NRSEQLINHA := '';
               V_NRLINHA    := '';
               V_CDPRODUTO  := '';
         END;

        IF (((V_NRSEQLINHA = '')OR(V_NRSEQLINHA IS NULL)) AND ((V_CDPRODUTO = '')OR(V_CDPRODUTO IS NULL))) THEN

          --Insere a linha
          INSERT INTO RELCOMPITEMPED (CDFILIAL, NRPEDIDO, NRITEMPED, CDPRODUTOPAI,
                                      NRLINHA, NRSEQLINHA,
                                      CDPRODUTO6, NMPRODUTO6, QTPRODUTO6)
            VALUES (C_COMP.CDFILIAL, C_COMP.NRPEDIDO, C_COMP.NRITEMPED, C_COMP.CDPRODUTO,
                    C_COMP.CDGRUPOCOMP, 1,
                    C_COMP.CDPRODCOMPED, C_COMP.PRODFILHO, C_COMP.QTITCOMPPROD);

        ELSIF ((V_CDPRODUTO = '')OR(V_CDPRODUTO IS NULL)) THEN

          --Altera a linha que j existe
          UPDATE RELCOMPITEMPED
             SET CDPRODUTO6    = C_COMP.CDPRODCOMPED,
                 NMPRODUTO6    = C_COMP.PRODFILHO,
                 QTPRODUTO6    = C_COMP.QTITCOMPPROD
           WHERE (CDFILIAL     = C_COMP.CDFILIAL   )
             AND (NRPEDIDO     = C_COMP.NRPEDIDO   )
             AND (NRITEMPED    = C_COMP.NRITEMPED  )
             AND (CDPRODUTOPAI = C_COMP.CDPRODUTO  )
             AND (NRLINHA      = C_COMP.CDGRUPOCOMP)
             AND (NRSEQLINHA   = 1               );

        ELSE

           -- Procedure que vai adicionando sublinhas recursivamente conforme a necessidade.
           REL_COMPITEMPED_RECURSIVA (C_COMP.CDFILIAL, C_COMP.NRPEDIDO, C_COMP.NRITEMPED, C_COMP.CDPRODUTO,
                                      C_COMP.CDGRUPOCOMP, 2, C_COMP.CDPRODCOMPED, C_COMP.PRODFILHO, C_COMP.QTITCOMPPROD, C_COMP.NRSEQPROD);
        END IF;
      END IF;

      -- Sbado
      IF (C_COMP.NRSEQPROD = '7') THEN

        -- Verifica se a linha existe
        BEGIN
           SELECT MIN(NRSEQLINHA) AS NRSEQLINHA, NRLINHA, CDPRODUTO7
             INTO V_NRSEQLINHA, V_NRLINHA, V_CDPRODUTO
             FROM RELCOMPITEMPED
            WHERE (CDFILIAL     = C_COMP.CDFILIAL   )
              AND (NRPEDIDO     = C_COMP.NRPEDIDO   )
              AND (NRITEMPED    = C_COMP.NRITEMPED  )
              AND (CDPRODUTOPAI = C_COMP.CDPRODUTO  )
              AND (NRLINHA      = C_COMP.CDGRUPOCOMP)
          --    AND ((CDPRODUTO7 IS NULL) OR (C_COMP.CDGRUPOCOMP = NRLINHA))
              AND ROWNUM <= 1
            GROUP BY NRLINHA, CDPRODUTO7;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_NRSEQLINHA := '';
               V_NRLINHA    := '';
               V_CDPRODUTO  := '';
         END;

        IF (((V_NRSEQLINHA = '')OR(V_NRSEQLINHA IS NULL)) AND ((V_CDPRODUTO = '')OR(V_CDPRODUTO IS NULL))) THEN

          --Insere a linha
          INSERT INTO RELCOMPITEMPED (CDFILIAL, NRPEDIDO, NRITEMPED, CDPRODUTOPAI,
                                      NRLINHA, NRSEQLINHA,
                                      CDPRODUTO7, NMPRODUTO7, QTPRODUTO7)
            VALUES (C_COMP.CDFILIAL, C_COMP.NRPEDIDO, C_COMP.NRITEMPED, C_COMP.CDPRODUTO,
                    C_COMP.CDGRUPOCOMP, 1,
                    C_COMP.CDPRODCOMPED, C_COMP.PRODFILHO, C_COMP.QTITCOMPPROD);

        ELSIF ((V_CDPRODUTO = '')OR(V_CDPRODUTO IS NULL)) THEN

          --Altera a linha que j existe
          UPDATE RELCOMPITEMPED
             SET CDPRODUTO7    = C_COMP.CDPRODCOMPED,
                 NMPRODUTO7    = C_COMP.PRODFILHO,
                 QTPRODUTO7    = C_COMP.QTITCOMPPROD
           WHERE (CDFILIAL     = C_COMP.CDFILIAL   )
             AND (NRPEDIDO     = C_COMP.NRPEDIDO   )
             AND (NRITEMPED    = C_COMP.NRITEMPED  )
             AND (CDPRODUTOPAI = C_COMP.CDPRODUTO  )
             AND (NRLINHA      = C_COMP.CDGRUPOCOMP)
             AND (NRSEQLINHA   = 1               );

        ELSE

           -- Procedure que vai adicionando sublinhas recursivamente conforme a necessidade.
           REL_COMPITEMPED_RECURSIVA (C_COMP.CDFILIAL, C_COMP.NRPEDIDO, C_COMP.NRITEMPED, C_COMP.CDPRODUTO,
                                      C_COMP.CDGRUPOCOMP, 2, C_COMP.CDPRODCOMPED, C_COMP.PRODFILHO, C_COMP.QTITCOMPPROD, C_COMP.NRSEQPROD);
        END IF;
      END IF;        
   END LOOP;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('RELATORIO_COMPITEMPEDIDO','6.05.xxx'); END;
/